@@ -24,10 +24,10 @@ public:
         setOperation(op);
         setError(QNetworkReply::ContentAccessDenied, QStringLiteral("Blocked request."));
         const auto networkError = error();
-        QMetaObject::invokeMethod(this, "error", Qt::QueuedConnection, Q_ARG(QNetworkReply::NetworkError, networkError));
+        QMetaObject::invokeMethod(this, &QNetworkReply::errorOccurred, Qt::QueuedConnection, networkError);
 
         setFinished(true);
-        Q_EMIT QMetaObject::invokeMethod(this, "finished", Qt::QueuedConnection);
+        Q_EMIT QMetaObject::invokeMethod(this, &QNetworkReply::finished, Qt::QueuedConnection);
     }
     qint64 readData(char * /*data*/, qint64 /*maxSize*/) override
     {
