@@ -9,7 +9,7 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include <KPackage/PackageLoader>
 
 #include "kscreensaversettings.h"
-#include "lnf_integration.h"
+#include "shell_integration.h"
 #include "wallpaper_integration.h"
 
 AppearanceSettings::AppearanceSettings(QObject *parent)
@@ -17,9 +17,9 @@ AppearanceSettings::AppearanceSettings(QObject *parent)
 {
 }
 
-QUrl AppearanceSettings::lnfConfigFile() const
+QUrl AppearanceSettings::shellConfigFile() const
 {
-    return m_lnfConfigFile;
+    return m_shellConfigFile;
 }
 
 QUrl AppearanceSettings::wallpaperConfigFile() const
@@ -35,12 +35,12 @@ KConfigPropertyMap *AppearanceSettings::wallpaperConfiguration() const
     return m_wallpaperIntegration->configuration();
 }
 
-KConfigPropertyMap *AppearanceSettings::lnfConfiguration() const
+KConfigPropertyMap *AppearanceSettings::shellConfiguration() const
 {
-    if (!m_lnfIntegration) {
+    if (!m_shellIntegration) {
         return nullptr;
     }
-    return m_lnfIntegration->configuration();
+    return m_shellIntegration->configuration();
 }
 
 ScreenLocker::WallpaperIntegration *AppearanceSettings::wallpaperIntegration() const
@@ -51,11 +51,11 @@ ScreenLocker::WallpaperIntegration *AppearanceSettings::wallpaperIntegration() c
 void AppearanceSettings::load()
 {
     loadWallpaperConfig();
-    loadLnfConfig();
+    loadShellConfig();
 
-    if (m_lnfSettings) {
-        m_lnfSettings->load();
-        Q_EMIT m_lnfSettings->configChanged(); // To force the ConfigPropertyMap to reevaluate
+    if (m_shellSettings) {
+        m_shellSettings->load();
+        Q_EMIT m_shellSettings->configChanged(); // To force the ConfigPropertyMap to reevaluate
     }
 
     if (m_wallpaperSettings) {
@@ -66,8 +66,8 @@ void AppearanceSettings::load()
 
 void AppearanceSettings::save()
 {
-    if (m_lnfSettings) {
-        m_lnfSettings->save();
+    if (m_shellSettings) {
+        m_shellSettings->save();
     }
 
     if (m_wallpaperSettings) {
@@ -77,9 +77,9 @@ void AppearanceSettings::save()
 
 void AppearanceSettings::defaults()
 {
-    if (m_lnfSettings) {
-        m_lnfSettings->setDefaults();
-        Q_EMIT m_lnfSettings->configChanged(); // To force the ConfigPropertyMap to reevaluate
+    if (m_shellSettings) {
+        m_shellSettings->setDefaults();
+        Q_EMIT m_shellSettings->configChanged(); // To force the ConfigPropertyMap to reevaluate
     }
 
     if (m_wallpaperSettings) {
@@ -92,8 +92,8 @@ bool AppearanceSettings::isDefaults() const
 {
     bool defaults = true;
 
-    if (m_lnfSettings) {
-        defaults &= m_lnfSettings->isDefaults();
+    if (m_shellSettings) {
+        defaults &= m_shellSettings->isDefaults();
     }
 
     if (m_wallpaperSettings) {
@@ -106,8 +106,8 @@ bool AppearanceSettings::isSaveNeeded() const
 {
     bool saveNeeded = false;
 
-    if (m_lnfSettings) {
-        saveNeeded |= m_lnfSettings->isSaveNeeded();
+    if (m_shellSettings) {
+        saveNeeded |= m_shellSettings->isSaveNeeded();
     }
 
     if (m_wallpaperSettings) {
@@ -136,29 +136,24 @@ void AppearanceSettings::loadWallpaperConfig()
     Q_EMIT currentWallpaperChanged();
 }
 
-void AppearanceSettings::loadLnfConfig()
+void AppearanceSettings::loadShellConfig()
 {
-    if (m_package.isValid() && m_lnfIntegration) {
+    if (m_package.isValid() && m_shellIntegration) {
         return;
     }
 
-    Q_ASSERT(!m_package.isValid() && !m_lnfIntegration);
+    Q_ASSERT(!m_package.isValid() && !m_shellIntegration);
 
-    m_package = KPackage::PackageLoader::self()->loadPackage(QStringLiteral("Plasma/LookAndFeel"));
-    KConfigGroup cg(KSharedConfig::openConfig(QStringLiteral("kdeglobals")), "KDE");
-    const QString packageName = cg.readEntry("LookAndFeelPackage", QString());
-    if (!packageName.isEmpty()) {
-        m_package.setPath(packageName);
-    }
-
-    m_lnfIntegration = new ScreenLocker::LnFIntegration(this);
-    m_lnfIntegration->setPackage(m_package);
-    m_lnfIntegration->setConfig(KScreenSaverSettings::getInstance().sharedConfig());
-    m_lnfIntegration->init();
-    m_lnfSettings = m_lnfIntegration->configScheme();
+    m_package = KPackage::PackageLoader::self()->loadPackage(QStringLiteral("Plasma/Shell"));
+    m_shellIntegration = new ScreenLocker::ShellIntegration(this);
+    m_package.setPath(m_shellIntegration->defaultShell());
+    m_shellIntegration->setPackage(m_package);
+    m_shellIntegration->setConfig(KScreenSaverSettings::getInstance().sharedConfig());
+    m_shellIntegration->init();
+    m_shellSettings = m_shellIntegration->configScheme();
 
     auto sourceFile = m_package.fileUrl(QByteArrayLiteral("lockscreen"), QStringLiteral("config.qml"));
-    m_lnfConfigFile = sourceFile;
+    m_shellConfigFile = sourceFile;
 }
 
 #include "moc_appearancesettings.cpp"
